summaryrefslogtreecommitdiffstats
path: root/views/box_layout.h
diff options
context:
space:
mode:
authorjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-20 21:35:32 +0000
committerjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-20 21:35:32 +0000
commitdf0f6e8f05dcab26f0e53bda494cb0d22ae315d0 (patch)
tree117d1fc17719bff500b9f2c2552789dc23d83ebb /views/box_layout.h
parent706dbc20653f11019797dcb2bdfee2e9e83b0fba (diff)
downloadchromium_src-df0f6e8f05dcab26f0e53bda494cb0d22ae315d0.zip
chromium_src-df0f6e8f05dcab26f0e53bda494cb0d22ae315d0.tar.gz
chromium_src-df0f6e8f05dcab26f0e53bda494cb0d22ae315d0.tar.bz2
Display an infobar when content settings were created.
The xib changes add a gradient view with an icon and a text field that is displayed as infobar. The text field is set to truncate. The blocked cookies label is set to wrap. The various views are connected to the new outlets. win: http://imgur.com/OmTxr.png linux: http://imgur.com/OmTxr mac: http://imgur.com/VbwFp BUG=49826 TEST=unit_tests Review URL: http://codereview.chromium.org/3108029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@56913 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'views/box_layout.h')
-rw-r--r--views/box_layout.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/views/box_layout.h b/views/box_layout.h
index ffce6f8..2e86d9b 100644
--- a/views/box_layout.h
+++ b/views/box_layout.h
@@ -23,11 +23,13 @@ class BoxLayout : public LayoutManager {
kVertical,
};
// Use |inside_border_spacing| to add additional space between the child view
// area and the host view border. |between_child_spacing| controls the space
// in between child views.
BoxLayout(Orientation orientation,
- int inside_border_spacing,
+ int inside_border_horizontal_spacing,
+ int inside_border_vertical_spacing,
int between_child_spacing);
virtual ~BoxLayout() {}
@@ -39,7 +41,9 @@ class BoxLayout : public LayoutManager {
const Orientation orientation_;
// Spacing between child views and host view border.
- const int inside_border_spacing_;
+ const int inside_border_horizontal_spacing_;
+ const int inside_border_vertical_spacing_;
+
// Spacing to put in between child views.
const int between_child_spacing_;
@@ -23,11 +23,13 @@ class BoxLayout : public LayoutManager {
kVertical,
};
- // Use |inside_border_spacing| to add additional space between the child view
- // area and the host view border. |between_child_spacing| controls the space
- // in between child views.
+ // Use |inside_border_horizontal_spacing| and
+ // |inside_border_vertical_spacing| to add additional space between the child
+ // view area and the host view border. |between_child_spacing| controls the
+ // space in between child views.
BoxLayout(Orientation orientation,